@@ -104,8 +104,9 @@ sub combinate_object {
     }
     else {
         require YAML::PP;
-        die "Can't combinate:\n" .
-            YAML::PP->new(schema => ['Core', 'Perl'])->dump_string($object);
+        die "Can't combinate:\n" . YAML::PP
+            ->new(schema => ['Core', 'Perl'])
+            ->dump_string($object);
     }
 }
 
@@ -162,16 +163,20 @@ sub perl_regexes {
 sub to_yaml {
     require YAML::PP;
     my $self = shift;
-    my $yaml = YAML::PP->new(schema => ['Core', 'Perl'])
-                       ->dump_string($self->tree);
-    $yaml =~ s/\n *(\[\]\n)/ $1/g; # Work around YAML::PP formatting issue
-    return $yaml;
+    YAML::PP
+        ->new(schema => ['Core', 'Perl'])
+        ->dump_string($self->tree);
 }
 
 sub to_json {
     require JSON::PP;
     my $self = shift;
-    return JSON::PP->new->utf8->canonical->pretty->encode($self->tree);
+    JSON::PP
+        ->new
+        ->utf8
+        ->canonical
+        ->pretty
+        ->encode($self->tree);
 }
 
 sub to_perl {
